@@ -3,9 +3,11 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.120927';
+our $VERSION = '0.130104';
 
 use Acme::CPANAuthors::Register (
+    ACE       => 'yuichi tsunoda',
+    ACIDLEMON => 'Masatoshi Kawazoe',
     AERDAN    => 'Kiyoshi Aman',
     AGREW     => 'Naoyuki Okumura',
     AHIROSE   => 'Akira HIROSE',
@@ -52,7 +54,9 @@ use Acme::CPANAuthors::Register (
     HAMANO    => 'Tsukasa Hamano',
     HAOYAYOI  => 'Soshi Tamura',
     HATA      => 'Masanori HATA',
+    HATAK     => 'Hisashi HATAKEYAMA',
     HATTORI   => 'Fumiaki Hattori',
+    HAYAJO    => 'Hayato Imai',
     HAYASHI   => 'Hiroo HAYASHI',
     HEDWIG    => 'Yusuke Sugiyama',
     HHORIUCHI => 'Hiroki Horiuchi',
@@ -71,6 +75,7 @@ use Acme::CPANAuthors::Register (
     HIROYUKIM => 'Yamanaka Hiroyuki',
     HRYK      => 'Hiroyuki Nakamura',
     HKOBA     => 'KOBAYASI, Hiroaki',
+    HOKKE     => 'Yoichi Hirota',
     HOLLY     => 'Akira Horimoto',
     HORIUCHI  => 'Yasuhiro Horiuchi',
     HRK       => 'Haruka Kataoka',
@@ -88,6 +93,7 @@ use Acme::CPANAuthors::Register (
     JAMADAM   => 'Sugama Keita',
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
+    JUDIOO    => 'Udo Oji',
     JUNICHIRO => 'Junichiro Tobe',
     KAMIPO    => 'Ryuta Kamizono',
     KAMO      => 'Yoshikazu Kamoshida',
@@ -96,6 +102,7 @@ use Acme::CPANAuthors::Register (
     KAWASAKI  => 'Kawasaki Yusuke',
     KAZEBURO  => 'Masahiro Nagano',
     KAZUHO    => 'Kazuho Oku',
+    KAZUKIMA  => 'Kazuki MATSUDA',
     KAZUNORI  => 'Kazunori Minoda',
     KEISUKE   => 'Keisuke Kuramata',
     KENJIRO   => 'Kenjiro Hirakawa',
@@ -135,8 +142,10 @@ use Acme::CPANAuthors::Register (
     KZTOMITA  => 'Kazuyoshi Tomita',
     KZYS      => 'Kato Kazuyoshi',
     LAPIS     => 'Junichi Iwasaki',
+    LIMITUSUS => 'Tomoya KABE',
     LUSHE     => 'Masatoshi Mizuno',
     LYOKATO   => 'Lyo Kato',
+    MAGICDRIV => 'Hiroshi IKEGAMI',
     MAHIRO    => 'Mahiro Ando',
     MAHITO    => 'Hogelist',
     MAIDO     => 'Masahiro Funakoshi',
@@ -161,6 +170,7 @@ use Acme::CPANAuthors::Register (
     MIYAZAKI  => 'Ittetsu Miyazaki',
     MIZZY     => 'Gosuke Miyashita',
     MORIYA    => 'Moriya Masaki',
+    MOZNION   => 'Taiki Kawakami',
     MURATA    => 'Shingo Murata',
     MURATAYA  => 'MURATA Yasuhisa',
     MYUJI     => 'Yuji Maeda',
@@ -193,6 +203,7 @@ use Acme::CPANAuthors::Register (
     OYAMA     => 'Hiroyuki OYAMA',
     OZAWA     => 'OZAWA Sakuro',
     PAINA     => 'SATO Taisuke',
+    PAPIX     => 'Takayuki Fukumoto',
     PAWAPAWA  => 'Kohei Yoshioka',
     PEN       => 'Abe Masahiro',
     PERFORB   => 'Yusuke Maeda',
@@ -202,6 +213,7 @@ use Acme::CPANAuthors::Register (
     POPPEN    => 'Shinsuke Matsui',
     QUEEN     => 'Yasuhiro Miyazaki',
     RINTARO   => 'Rintaro Ishizaki',
+    RITOU     => 'Ryo Ito',
     RIYWO     => 'Ryosuke IWANAGA',
     ROZARY    => 'Syunsuke Fujishiro',
     RYOCHIN   => 'Okamoto RYO',
@@ -209,6 +221,7 @@ use Acme::CPANAuthors::Register (
     SASAO     => 'SASAO Takahiro',
     SASAZUKA  => 'Seiji Sasazuka',
     SATOH     => 'cho45 (SATOH, Hiroh)',
+    SAWAMUR   => 'Masaki  Sawamura',
     SAYANO    => 'Satoru Yano',
     SEKIMURA  => 'Masayoshi Sekimura',
     SERA      => 'Kazuhiro Sera',
@@ -239,6 +252,7 @@ use Acme::CPANAuthors::Register (
     SYOHEX    => 'Syohei Yoshida',
     SZARATE   => 'Santiago Zarate',
     TAGOMORIS => 'Satoshi Tagomori',
+    TAILRIVER => 'Shinsuke Ogawa',
     TAIY      => 'Taisuke Yamada',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
@@ -247,6 +261,7 @@ use Acme::CPANAuthors::Register (
     TAKERU    => 'Takeru INOUE',
     TAKESAKO  => 'Yoshinori TAKESAKO',
     TAKESHIGE => 'Ken Takeshige',
+    TAKESHUN  => 'Shun Takeyama',
     TAKKYUN   => 'Takayuki Ikeda',
     TAMAKOTO  => 'Tanaka Makoto',
     TAMASHIRO => 'Yuji Tamashiro',
@@ -281,6 +296,7 @@ use Acme::CPANAuthors::Register (
     TYPESTER  => 'Daisuke Murase',
     UASI      => 'Tomoki Aonuma',
     UMEMOTO   => 'Hajimu Umemoto',
+    UMEYUKI   => 'Hiromitsu Ito',
     UNLEARNED => 'Takashi Uesugi',
     USUALOMA  => 'Taku Amano',
     WATA      => 'Kouji Watanabe',
@@ -289,6 +305,7 @@ use Acme::CPANAuthors::Register (
     XAICRON   => 'Yuji Shimada',
     XOR       => 'Izumi Kawashima',
     XCEZX     => 'Tsuyoshi Maekawa',
+    YAKEX     => 'Yasutaka ATARASHI',
     YAMAMOTO  => 'Ryuzo Yamamoto',
     YAMATO    => 'Toshiyuki Yamato',
     YANA      => 'Toshimitu Yanagisawa',
@@ -298,6 +315,7 @@ use Acme::CPANAuthors::Register (
     YASUHIRO  => 'Yasuhiro Onishi',
     YAYOHEI   => 'Yohei Yamamoto',
     YIBE      => 'Yuki Ibe',
+    YOSHIAKI  => 'Yoshiaki Shiokawa',
     YOSHIDA   => 'Hironori Yoshida',
     YOSHIMI   => 'Keiji Yoshimi',
     YOSTY     => 'Koji Komatsu',
@@ -313,6 +331,7 @@ use Acme::CPANAuthors::Register (
     YUSUKE    => 'Yusuke Shibata',
     YUSUKEBE  => 'Yusuke Wada',
     YUTA      => 'MASUDA Yuta',
+    YUUKI     => 'Yuuki Tsubouchi',
     YUYAW     => 'Yuya Watanabe',
     ZENTOOO   => 'Naosuke Yokoe',
     ZIGOROU   => 'Toru Yamaguchi',
